#!/usr/bin/env python
"""Django's command-line utility for administrative tasks."""
import logging
import os
import sys

from django.db.migrations import writer

if len(sys.argv) > 1 and sys.argv[1] == 'test':
    logging.disable(logging.WARNING)


writer.MIGRATION_HEADER_TEMPLATE = """\
# Generated by Django %(version)s on %(timestamp)s
# flake8: noqa

"""

def main():
    """Run administrative tasks."""
    cmd = len(sys.argv) > 1 and sys.argv[1]
    os.environ.setdefault(
        "DJANGO_SETTINGS_MODULE",
        cmd == 'test' and "tests.settings.dev" or "pfx.settings.dev")
    try:
        from django.core.management import execute_from_command_line
    except ImportError as exc:
        raise ImportError(
            "Couldn't import Django. Are you sure it's installed and "
            "available on your PYTHONPATH environment variable? Did you "
            "forget to activate a virtual environment?"
        ) from exc
    execute_from_command_line(sys.argv)


if __name__ == '__main__':
    main()
